@@ -45,6 +45,9 @@
 #define CRASHREPORT_HELPER "/usr/share/apport/apport-checkreports"
 #define CRASHREPORT_REPORT_APP "/usr/share/apport/apport-gtk"
 #define CRASHREPORT_DIR "/var/crash/"
+#define CRASHREPORT_AUTOREPORT "/var/lib/apport/autoreport"
+#define CRASHREPORT_WHOOPSIE_EXEC "/usr/bin/whoopsie"
+#define CRASHREPORT_WHOOPSIE_SERVICE "whoopsie"
 #define UNICAST_LOCAL_AVAHI_FILE "/run/avahi-daemon/disabled-for-unicast-local"
 #define LIVEPATCH_FILE "/var/snap/canonical-livepatch/current/status"
 
